Display orthogonal projection on principal Cartesian planes, with scene centre in the image centre.
Usage
rgl.orthoview(plane = "xy", fov = 0, ...)
Value
None
Arguments
plane
character string, which can be either of `xy`, `yx`, `yz`, `zy`, `zx`, `xz`, where the first letter is the axis displayed from left to right and the second letter is the axis displayed from bottom to top. The third axis points either out of the screen or into the screen following the right-hand convention.